/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal;

import java.util.List;

import org.conqat.ide.commons.ui.logging.LoggingUtils;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.ToolingKernelActivator;
import org.fortiss.tooling.kernel.base.EObjectAwareServiceBase;
import org.fortiss.tooling.kernel.ui.interfaces.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.services.IModelElementService;

/**
 * This class implements the {@link IModelElementService} interface. It requires
 * a unique and singleton model element handler per model element class.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 9D99C615FF981BE0831593DC3600D498
 */
public class ModelElementService extends
		EObjectAwareServiceBase<IModelElementHandler<EObject>> implements
		IModelElementService {

	/** The model element handler extension point ID. */
	private static final String EXTENSION_POINT_NAME = "org.fortiss.tooling.kernel.ui.modelElementHandler";

	/** The model element handler configuration element name. */
	private static final String CONFIGURATION_ELEMENT_NAME = "modelElementHandler";

	/** The model element handler class attribute name. */
	private static final String HANDLER_CLASS_ATTRIBUTE_NAME = "handler";

	/** {@inheritDoc} */
	@Override
	public IModelElementHandler<EObject> getModelElementHandler(
			EObject modelElement) {
		Class<? extends EObject> clazz = modelElement.getClass();
		List<IModelElementHandler<EObject>> handlerList = getRegisteredHandlers(clazz);
		if (handlerList == null || handlerList.isEmpty()) {
			LoggingUtils.error(ToolingKernelActivator.getDefault(),
					"No matching model element handler found for " + clazz,
					null);
			return null;
		}
		return handlerList.get(0);
	}

	/** {@inheritDoc} */
	@Override
	protected boolean requiresUniqueHandler() {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	protected String getExtensionPointName() {
		return EXTENSION_POINT_NAME;
	}

	/** {@inheritDoc} */
	@Override
	protected String getConfigurationElementName() {
		return CONFIGURATION_ELEMENT_NAME;
	}

	/** {@inheritDoc} */
	@Override
	protected String getHandlerClassAttribute() {
		return HANDLER_CLASS_ATTRIBUTE_NAME;
	}
}
