/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.services;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.ui.interfaces.IEditorBinding;
import org.fortiss.tooling.kernel.ui.internal.EditorService;

/**
 * The editor service handles editor registration. It also allows opening and
 * closing of editors.
 * 
 * @see IEditorBinding
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: ECCFA2C956D54381EC206F79876D8BC1
 */
public interface IEditorService {

	/** Returns the singleton instance of the service. */
	public static final IEditorService INSTANCE = new EditorService();

	/** Opens an editor for the given element. */
	void openInEditor(EObject element);

	/** Closes editors which depend on the given element or a sub-element. */
	void closeEditors(EObject rootElement);

	/** Returns registered editor bindings for the given {@link EObject}. */
	List<IEditorBinding<EObject>> getBindings(EObject element);
}
