/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal;

import java.util.LinkedList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.base.EObjectAwareServiceBase;
import org.fortiss.tooling.kernel.interfaces.IConstraintChecker;
import org.fortiss.tooling.kernel.interfaces.IConstraintViolation;
import org.fortiss.tooling.kernel.services.IConstraintService;

/**
 * This class implements the {@link IConstraintService} interface.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: 9E0D8411A1525AA3989DED2C0DC7A033
 */
public class ConstraintService extends
		EObjectAwareServiceBase<IConstraintChecker<? extends EObject>>
		implements IConstraintService {

	/** The compositor extension point ID. */
	private static final String EXTENSION_POINT_NAME = "org.fortiss.tooling.kernel.modelElementConstraintChecker";

	/** The compositor configuration element name. */
	private static final String CONFIGURATION_ELEMENT_NAME = "modelElementConstraintChecker";

	/** The compositor class attribute name. */
	private static final String HANDLER_CLASS_ATTRIBUTE_NAME = "checker";

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	public List<IConstraintViolation<? extends EObject>> performAllConstraintChecks(
			EObject modelElement) {
		List<IConstraintViolation<? extends EObject>> result = new LinkedList<IConstraintViolation<? extends EObject>>();
		for (IConstraintChecker<? extends EObject> checker : getRegisteredHandlers(modelElement
				.getClass())) {
			if (checker.isApplicable(modelElement)) {
				result.add(checker.apply(modelElement));
			}
		}
		return result;
	}

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	public List<IConstraintChecker<? extends EObject>> getAllConstraintCheckers(
			EObject modelElement) {
		return getRegisteredHandlers(modelElement.getClass());
	}

	/** {@inheritDoc} */
	@Override
	protected String getExtensionPointName() {
		return EXTENSION_POINT_NAME;
	}

	/** {@inheritDoc} */
	@Override
	protected String getConfigurationElementName() {
		return CONFIGURATION_ELEMENT_NAME;
	}

	/** {@inheritDoc} */
	@Override
	protected String getHandlerClassAttribute() {
		return HANDLER_CLASS_ATTRIBUTE_NAME;
	}
}
